@@ -3,9 +3,15 @@
 
 from trytond.pool import Pool
 from .work import *
+from .timesheet import *
+from . import party
 
 
 def register():
     Pool.register(
         Work,
+        TimesheetWork,
         module='project', type_='model')
+    Pool.register(
+        party.PartyReplace,
+        module='project', type_='wizard')
