@@ -84,9 +84,8 @@ class Work(sequence_ordered(), ModelSQL, ModelView):
         left='left', right='right', ondelete='RESTRICT',
         domain=[
             ('company', '=', Eval('company', -1)),
-            ('id', '!=', Eval('id', -1)),
             ],
-        depends=['company', 'id'])
+        depends=['company'])
     left = fields.Integer('Left', required=True, select=True)
     right = fields.Integer('Right', required=True, select=True)
     children = fields.One2Many('project.work', 'parent', 'Children',
@@ -230,6 +229,7 @@ class Work(sequence_ordered(), ModelSQL, ModelView):
     @classmethod
     def validate(cls, works):
         super(Work, cls).validate(works)
+        cls.check_recursion(works, rec_name='name')
         for work in works:
             work.check_state()
 
